(ns blog.env)

(defn get-port
  "Gets the environment variable PORT. If no variable, then the default port is 3000. Server will listen requests on this port."
  []
  (or (-> (.-env js/process)
          (.-PORT))
      "3000"))

(defn get-secret
  "Gets the environment variable SECRET. If no variable, then the server will be crashed."
  []
  (or (-> (.-env js/process)
          (.-SECRET))
      (do
        (js/console.log "[ERROR] Set enviroment variable SECRET!!!")
        (js/process.exit 1))))

(defn get-database-credentials
  "Gets the postgres credentials. Defaults: host - postgres, port - 5432, database - postgres, user - postgres, password - 'changeme!!!'."
  []
  (let [env (.-env js/process)]
    {:host (or (.-POSTGRES_HOST env) "postgres")
     :port (or (.-POSTGRES_PORT env) 5432)
     :database (or (.-POSTGRES_DATABASE env) "postgres")
     :user (or (.-POSTGRES_USER env) "postgres")
     :password (or (.-POSTGRES_PASSWORD env) "changeme!!!")}))

